@@ -3,18 +3,17 @@ use warnings; use strict;
 
 =head1 NAME
 
-Elive - Elluminate Live! (c) SDK bindings
+Elive - Elluminate Live! (c) Command Toolkit bindings
 
 =head1 VERSION
 
-Version 0.74_2
+Version 0.87.1
 
 =cut
 
-our $VERSION = '0.74_2';
+our $VERSION = '0.87.1';
 
-use Class::Data::Inheritable;
-use base qw{Class::Data::Inheritable};
+use parent qw{Class::Data::Inheritable};
 use Scalar::Util;
 
 use YAML;
@@ -27,11 +26,11 @@ The following (somewhat contrived) example sets up a meeting of selected
 participants:
 
     use Elive;
-    use Elive::Connection;
     use Elive::Entity::User;
-    use Elive::Entity::Meeting;
+    use Elive::Entity::Preload;
+    use Elive::View::Session;
 
-    my $MeetingName = 'Meeting of the Smiths';
+    my $meeting_name = 'Meeting of the Smiths';
 
     Elive->connect('http://someEllumServer.com/test',
                    'serversupport', 'mypass');
@@ -42,26 +41,28 @@ participants:
     my $start = time() + 15 * 60; # starts in 15 minutes
     my $end   = $start + 30 * 60; # runs for half an hour
 
-    my $meeting = Elive::Entity::Meeting->insert({
-	 name           => $MeetingName,
+    # upload whiteboard content
+    #
+    my $preload = Elive::Entity::Preload->upload('welcome.wbd');
+
+    my $meeting = Elive::View::Session->insert({
+	 name           => $meeting_name,
 	 facilitatorId  => Elive->login,
 	 start          => $start . '000',
 	 end            => $end   . '000',
+         participants   => $participants,
+         add_preload    => $preload,
 	 });
 
-    my $participant_list = $meeting->participant_list;
-    $participant_list->participants($participants);
-    $participant_list->update;
-
     Elive->disconnect;
 
 =head1 DESCRIPTION
 
 Elive is a set of Perl bindings and entity definitions for the Elluminate
-I<Live!> SDK.
+I<Live!> Command Toolkit; in particular, the entity commands.
 
-The Elluminate SDK runs as a SOAP service and can be used to automate the
-raising, management and connection to meetings; and other related entities,
+These commands are available as a SOAP web service and can be used to automate
+the raising, management and connection to meetings; and other related entities,
 including users, groups, preloads and recordings.
 
 =head1 BACKGROUND
@@ -71,16 +72,14 @@ Elluminate I<Live!> (c) is software for virtual online classrooms.
 It is suitable for meetings, demonstrations web conferences, seminars
 and IT deployment, training and support.
 
-Users, Meetings and other resources are stored in a management database.
-These can be accessed and manipulated via the Elluminate I<Live!> SDK.
-
 Most actions that can be performed via the web interface can also be
-achieved via the SOAP SDK. This is known as the I<Command Toolkit> and
+achieved via SOAP web services. This is known as the I<Command Toolkit> and
 is detailed in chapter 4 of the Elluminate I<Live!> Software Developers
-Kit.
+Kit (SDK).
 
-This module provides Perl object bindings to Elluminate Live! entities via
-the Command Toolkit (SDK).
+Users, Meetings and other resources are stored in a management database.
+These can be accessed and manipulated via the Entity Commands in the
+Command Toolkit.
 
 =cut
 
@@ -102,9 +101,10 @@ Connects to an Elluminate server instance. Dies if the connection could not
 be established. If, for example, the SOAP connection or user login failed.
 
 The login user must either be an Elluminate I<Live!> system administrator
-account, or a user that has been granted access to the SDK (see README file).
+account, or a user that has been configured to access the Command Toolkit
+via web services.
 
-See also Elive::Connection.
+See also: The L<README> file; L<Elive::Connection::SDK>.
 
 =cut
 
@@ -268,14 +268,14 @@ Elluminate Services Errors:
 =item   "Unable to determine a command for the key : Xxxx"
 
 This may indicate that the particular command is is not available for your
-site instance. Please follow the instructions in the README file
-for detecting and repairing missing adapters.
+site instance. Please follow the instructions in the README file for
+detecting and repairing missing adapters.
 
 =item   "User [<username>], not permitted to access the command {<command>]"
 
 Please ensure that the user is a sytem administrator account and/or the
-user has been configured for SDK access. See also the instruction in the
-README file.
+user has been configured to access commands via web services. See also the
+L<README> file.
 
 =back
 
@@ -292,11 +292,11 @@ script, and can be used to confirm basic operation of Elive.
 It server a secondary function of querying entity metadata. For example,
 to show the user entity:
 
-    $> elive_query
+    % elive_query
     Elive query 0.xx  - type 'help' for help
 
     elive> show
-    usage: show group|meeting|meetingParameters|participantList|preload|recording|serverDetails|serverParameters|use
+    usage: show group|meeting|meetingParameters|participantList|preload|recording|serverDetails|serverParameters|session|users
 
     elive> show meeting
     meeting: Elive::Entity::Meeting:
@@ -326,56 +326,56 @@ see the README file.
 
 =head1 SEE ALSO
 
-L<Elive::API> - This is a separate CPAN module that implements the alternate Elluminate I<Live!> Standard Bridge API. 
-
-The following classes are included in this distribution and implement the SDK bindings:
+=head2 Modules in the Elive distribution
 
 =over 4
 
-=item Elive::Connection::SDK - Elluminate SOAP connection
+=item L<Elive::Connection::SDK> - Elluminate SOAP connection
 
-=item Elive::Entity::Group
+=item L<Elive::View::Session>
 
-=item Elive::Entity::Meeting
+=item L<Elive::Entity::Group>
 
-=item Elive::Entity::MeetingParameters
+=item L<Elive::Entity::ParticipantList>
 
-=item Elive::Entity::ParticipantList
+=item L<Elive::Entity::Preload>
 
-=item Elive::Entity::Preload
+=item L<Elive::Entity::Recording>
 
-=item Elive::Entity::Recording
+=item L<Elive::Entity::Report>
 
-=item Elive::Entity::Report
-
-=item Elive::Entity::ServerDetails
-
-=item Elive::Entity::ServerParameters
-
-=item Elive::Entity::User
+=item L<Elive::Entity::User>
 
 =back
 
-Scripts (included in the Elive distribution):
+=head2 Scripts in the Elive Distribution
 
 =over 4
 
-=item elive_query - simple interactive queries on Elive entities
+=item L<elive_query> - simple interactive queries on Elive entities
 
-=item elive_raise_meeting - sample script that create meetings via one-liners
+=item L<elive_raise_meeting> - sample script that create meetings via one-liners
 
-=item elive_lint_config - sanity checker for  Elluminate site configurations
+=item L<elive_lint_config> - sanity checker for Elluminate server configurations
 
 =back
 
-Elluminate I<Live!> Documentation, installed with Elluminate.
+=head2 Related CPAN Modules
+
+L<Elive::StandardV2> - This is a separate CPAN module that implements the alternate Elluminate I<Live!> Standard Bridge API (v2). 
+
+=head2 Elluminate Documentation
+
+The following is either installed with Elluminate I<Live!> Documentation, or
+can be obtained from Elluminate.
 
 =over 4
 
 =item ELM2.5_SDK.pdf
 
-General Description of SDK's available for Elluminate I<Live!>. In particular
-see section 4 - the SOAP command toolkit.
+General Description of SDK developmenmt for Elluminate I<Live!>. In particular
+see section 4 - the SOAP Command Toolkit. This module concentrates on
+implementing the Entity Commands desribed in section 4.1.8.
 
 =item DatabaseSchema.pdf
 
@@ -387,33 +387,6 @@ Describes setting up multiple site instances.
 
 =back
 
-=head1 USAGE NOTES
-
-=over 4
-
-=item Database Access
-
-The Elluminate I<Live!> advanced configuration guide mentions that it can be
-configured to use other databases that support a JDBC bridge (most databases
-in widespread use). It specifically mentions SQL Server or Oracle. MySQL
-is supported with 9.5.0 
-
-=item LDAP Authentication
-
-Elluminate I<Live!> can also be configured to use an LDAP repository for
-user authentication.  Users can still be retrieved or listed.
-
-=over 4
-
-=item * You can map both of the user's I<userId> and I<loginName> to the
-LDAP I<uid> attribute.
-
-=item * Updates and deletes are not supported by the LDAP DAO adapter.
-
-=back
-
-=back
-
 =head1 AUTHOR
 
 David Warring, C<< <david.warring at gmail.com> >>
@@ -424,7 +397,7 @@ David Warring, C<< <david.warring at gmail.com> >>
 
 =item Elive is a newish module
 
-It has been used and tested against a number of sites running Elluminate 9.0
+It has been used and tested against a number of sites running Elluminate 9.5
 to 10.0.1.
 
 So far it does not implement all SOAP calls, but concentrates on entities
@@ -433,11 +406,11 @@ such as users, meetings, preloads and meeting participants.
 =item Elive does not support hosted (SAS) systems
 
 The Elive distribution only supports the Elluminate SDK which is implemented
-by ELM (Elluminate Live Manager) session manager. This SDK is not support by
+by ELM (Elluminate Live Manager) session manager. This SDK is not supported by
 SAS (Session Administration System).
 
-Update: See also the companion CPAN module L<Elive::API> which is under
-construction and will support the alternate Elluminate I<Live!> standard bridge.
+Update: See also the companion CPAN module L<Elive::StandardV2> which is under
+construction and will support the alternate Elluminate I<Live!> standard bridge (v2).
 
 =back
 
@@ -481,7 +454,7 @@ assistance with the development of this module.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2010 David Warring, all rights reserved.
+Copyright 2009-2011 David Warring, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
